@@ -60,7 +60,7 @@ aea_article <- function(..., keep_tex = TRUE,
 
 #' @section `agu_article`: Format for creating a American Geophysical Union
 #'   (AGU) article. Adapted from
-#'   <https://www.agu.org/Publish-with-AGU/Publish/#1>.
+#'   <https://www.agu.org/publish-with-agu/publish#1>.
 #' @export
 #' @rdname article
 agu_article <- function(..., keep_tex = TRUE,
@@ -169,7 +169,7 @@ ctex <- ctex_article
 
 #' @section `elsevier_article`: Format for creating submissions to Elsevier
 #'   journals. Adapted from
-#'   <https://www.elsevier.com/authors/policies-and-guidelines/latex-instructions>.
+#'   <https://www.elsevier.com/researcher/author/policies-and-guidelines/latex-instructions>.
 #'
 #' It requires a minimum version of 2.10 for Pandoc.
 #' @export
@@ -195,8 +195,12 @@ elsevier_article <- function(..., keep_tex = TRUE,
 #'   <https://www.frontiersin.org/about/author-guidelines>.
 #' @export
 #' @rdname article
-frontiers_article <- function(..., keep_tex = TRUE) {
-  pdf_document_format("frontiers", keep_tex = keep_tex, ...)
+frontiers_article <- function(..., keep_tex = TRUE, citation_package = "natbib") {
+  # check all arguments for format's default
+  if (citation_package != "natbib" && rmarkdown::pandoc_available("3.1.7")) {
+    stop("Frontiers template only supports 'natbib' for citation processing. Pandoc citeproc is no more compatible with the Frontier documentclass.")
+  }
+  pdf_document_format("frontiers", keep_tex = keep_tex, citation_package = citation_package,...)
 }
 
 
@@ -522,8 +526,8 @@ pnas_article <- function(..., keep_tex = TRUE) {
 }
 
 #' @section `sage_article`: Format for creating submissions to Sage
-#'   Journals. Based on the official Sage Journals
-#'   \verb{https://uk.sagepub.com/sites/default/files/sage_latex_template_4.zip}{class}.
+#'   Journals. Based on the official Sage Journals Class.
+#'   Available at `https://uk.sagepub.com/sites/default/files/sage_latex_template_4.zip`.
 #'
 #' Possible arguments for the YAML header are:
 #' * `title` title of the manuscript
@@ -549,7 +553,9 @@ sage_article <- function(..., highlight = NULL, citation_package = "natbib") {
 
 #' @section `sim_article`: Format for creating submissions to Statistics in
 #'   Medicine. Based on the official Statistics in Medicine
-#'   at `https://onlinelibrary.wiley.com/page/journal/10970258/homepage/la_tex_class_file.htm`.
+#'   at `https://authorservices.wiley.com/author-resources/Journal-Authors/Prepare/new-journal-design.html`.
+#'
+#'   This format uses xelatex by default as PDF engine to support the specific NJD fonts, per guideline.
 #'
 #' Possible arguments for the YAML header are:
 #' * `title` title of the manuscript
@@ -561,17 +567,18 @@ sage_article <- function(..., highlight = NULL, citation_package = "natbib") {
 #' * `received`, `revised`, `accepted` dates of submission, revision, and acceptance of the manuscript
 #' * `abstract` abstract, limited to 250 words
 #' * `keywords` up to 6 keywords
+#' * `abbreviations`, list of abbreviations and description separated by a comma
 #' * `bibliography` BibTeX `.bib` file
-#' * `classoption` options of the `WileyNJD-v2` class
+#' * `classoption` options of the `WileyNJD` class
 #' * `longtable` set to `true` to include the `longtable` package, used by default from `pandoc` to convert markdown to LaTeX code
 #' * `header-includes`: custom additions to the header, before the `\begin{document}` statement
 #' * `include-after`: for including additional LaTeX code before the `\end{document}` statement
 #' @export
 #' @rdname article
-sim_article <- function(..., highlight = NULL, citation_package = "natbib") {
+sim_article <- function(..., highlight = NULL, citation_package = "natbib", latex_engine = "xelatex") {
   pdf_document_format(
     "sim",
-    highlight = highlight, citation_package = citation_package, ...
+    highlight = highlight, citation_package = citation_package, latex_engine = latex_engine, ...
   )
 }
 
